@@ -1,14 +1,14 @@
 package String::JS;
 
-our $DATE = '2014-07-25'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-03-11'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
-use JSON;
-my $json = JSON->new->allow_nonref;
+use JSON::MaybeXS;
+my $json = JSON::MaybeXS->new->allow_nonref;
 
 use Exporter;
 our @ISA = qw(Exporter);
@@ -78,7 +78,7 @@ String::JS - Utilities for Javascript string literal representation
 
 =head1 VERSION
 
-This document describes version 0.02 of String::JS (from Perl distribution String-JS), released on 2014-07-25.
+This document describes version 0.03 of String::JS (from Perl distribution String-JS), released on 2016-03-11.
 
 =head1 FUNCTIONS
 
@@ -110,17 +110,13 @@ quotes (C<'>).
 
 Will die on failure.
 
-=head1 SEE ALSO
-
-L<JSON>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/String-JS>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-String-JS>.
+Source repository is at L<https://github.com/perlancar/perl-String-JS>.
 
 =head1 BUGS
 
@@ -132,11 +128,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
